# AI Governance Extension to the Meta Model
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension#overview)
  * [Activating the Extension](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension#activating-the-extension)
  * [Meta Model Additions](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension#meta-model-additions)
  * [Getting Insights from Reports](https://help.sap.com/docs/leanix/ea/meta-model-ai-governance-extension#getting-insights-from-reports)


Improve AI governance and adoption in your organization. Track and manage AI usage, evaluate risks, and assess AI potential.
